SQL language plugin for sqry
Implements the LanguagePlugin trait for SQL, providing:
- AST parsing with tree-sitter
This plugin enables semantic code search for SQL codebases, the #5 priority language for universal database query and data management (100% adoption in data-driven companies).
Re-exports
pub use relations::SqlGraphBuilder;
Modules
- relations
- SQL relation extraction and graph building Relation extraction for SQL - implements GraphBuilder for code graph construction.
Structs
- SqlPlugin
- SQL language plugin